@@ -1,11 +1,17 @@
 import os
+import logging
+
 from pathlib import Path
 
 from django.contrib import admin
-from django_backup_utils import models
+from django_backup_utils import models, helpers
 from django.utils.safestring import mark_safe
 from django.urls import reverse_lazy
 from django.contrib import messages
+from django.conf import settings
+from django_backup_utils.apps import BackupUtilsConfig
+
+logger = logging.getLogger(__name__)
 
 
 class BackupLogAdmin(admin.ModelAdmin):
@@ -28,17 +34,30 @@ class BackupLogAdmin(admin.ModelAdmin):
 
 
 class BackupAdmin(admin.ModelAdmin):
+
+    def __init__(self, model, admin_site, *args, **kwargs):
+        self.current_system_migrations_migrated, self.migration_files_found = helpers.get_system_migrations()
+        super(BackupAdmin, self).__init__(model, admin_site, *args, **kwargs)
+
     list_display = (
-        "pk", "backup", "size_mb", "created_at", "restore_link",
+        "pk", "backup", "size_mb", "created_at", "dump_version", "consistent_migrations", "restore_link",
         "system_migrations_migrated",
-        "system_migration_files", "dump_version", "system_version",)
-    readonly_fields = ("backup", 'size_bytes', "created_at", "system_migrations_migrated",
-                       "system_migration_files", "dump_version", "system_version", "params",)
+        "dump_migration_files",)
+    readonly_fields = (
+    "backup", 'size_bytes', "created_at", "dump_version", "consistent_migrations", "system_migrations_migrated",
+    "dump_migration_files", "params",)
     list_display_links = ("pk", "restore_link",)
 
     change_list_template = "django_backup_utils/backup_changelist.html"
     ordering = ("-created_at",)
 
+    def changelist_view(self, request, extra_context=None):
+        extra_context = {'system_migrations_migrated': self.current_system_migrations_migrated,
+                         'system_migration_files_found': self.migration_files_found,
+                         'ignore_consistency': BackupUtilsConfig.BACKUP_IGNORE_CONSISTENCY,
+                         'backup_system_version': settings.BACKUP_SYSTEM_VERSION}
+        return super(BackupAdmin, self).changelist_view(request, extra_context)
+
     def has_add_permission(self, request, obj=None):
         return False
 
@@ -55,6 +74,7 @@ class BackupAdmin(admin.ModelAdmin):
             backup = Path(obj.backup)
             if backup.is_file():
                 os.remove(backup)
+                logger.info(f"-> deleted file {backup}")
                 models.BackupLog.objects.create(message="deleted backup", module="admin:backup_delete",
                                                 output=f"deleted {backup}",
                                                 backup=obj.backup,
