@@ -2,6 +2,7 @@ import os
 import socket
 import tarfile
 import logging
+import inspect
 
 from distutils.util import strtobool
 
@@ -9,6 +10,7 @@ from pathlib import Path
 
 from django.conf import settings
 from django.db.migrations.recorder import MigrationRecorder
+from django.utils.dateparse import parse_datetime
 
 from django_backup_utils.apps import BackupUtilsConfig
 from django_backup_utils.exceptions import MigrationNotFound
@@ -85,8 +87,9 @@ def get_migration_file_list():
         if not BackupUtilsConfig.BACKUP_IGNORE_CONSISTENCY:
             raise MigrationNotFound(missing_migrations)
         else:
-            logger.warning(
-                f'some migration-files are missing, backup could be inconsistent missing:\n{missing_migrations}')
+            if (Path(str(inspect.getouterframes(inspect.currentframe())[1][1])).name) == 'createbackup.py':
+                logger.warning(
+                    f'some migration-files are missing, backup could be inconsistent missing:\n{missing_migrations}')
             consistent = False
 
     return migration_files, consistent
@@ -111,3 +114,20 @@ def extract_dumpinfo(tarpath):
     return {'created_at': created_at, "dump_version": dump_version,
             "system_migrations_migrated": system_migrations_migrated, "dump_migration_files": dump_migration_files,
             "params": params, 'consistent_migrations': consistent_migrations}
+
+
+def get_backup_list_by_time(backup_root, hostname=None, projectname=None, all=False):
+    files = os.listdir(backup_root)
+    paths = [os.path.join(backup_root, basename) for basename in files]
+    applicable = []
+    d = {}
+    if paths:
+        for each in paths:
+            backup = get_backup_name(each, hostname, projectname, all)
+            if backup:
+                d = {'path': backup, 'created_at': parse_datetime(extract_dumpinfo(Path(each)).get('created_at'))}
+                applicable.append(d)
+        sorted_list = sorted(applicable, key=lambda p: p["created_at"])
+        latest = sorted_list[-1].get('path')
+        return latest, sorted_list
+    return None, None
