@@ -1,23 +1,25 @@
 import os
-import sys
 import json
-import shutil
 import logging
+import os
+import shutil
+import subprocess
+import sys
 import tarfile
 import unittest
-import subprocess
-
 from pathlib import Path
 
 from django.conf import settings
 from django.core.management.base import BaseCommand
+from django.utils import timezone
+from django.utils.dateparse import parse_datetime
 
 from django_backup_utils import models
-from django_backup_utils.tests import loaddata
 from django_backup_utils.apps import BackupUtilsConfig
-from django_backup_utils.helpers import get_migration_file_list, get_system_migrations, get_backup_name, \
-    extract_dumpinfo
 from django_backup_utils.exceptions import MigrationNotFound, LoadException, UnittestFailed
+from django_backup_utils.helpers import get_migration_file_list, get_system_migrations, extract_dumpinfo, \
+    get_backup_list_by_time
+from django_backup_utils.tests import loaddata
 
 module = str(__name__).split(".")[-1]
 logger = logging.getLogger(__name__)
@@ -94,19 +96,6 @@ def delete_dir(dir, **kwargs):
         logger.debug(f"deleted directory {dir}")
 
 
-def latest_backup(backup_root):
-    files = os.listdir(backup_root)
-    paths = [os.path.join(backup_root, basename) for basename in files]
-
-    applicable = []
-    if paths:
-        for each in paths:
-            backup = get_backup_name(each)
-            if backup:
-                applicable.append(backup)
-        return max(applicable, key=os.path.getctime)
-
-
 def create_input():
     inp = input("continue y/N ? ")
     if str(inp) == "y" or str(inp) == "yes":
@@ -150,11 +139,11 @@ class Command(BaseCommand):
         self.context['params'] = params
 
         if not tarpath:
-            tar = latest_backup(settings.BACKUP_ROOT)
+            tar, sorted_backups = get_backup_list_by_time(settings.BACKUP_ROOT)
             if tar:
                 tarpath = Path(tar)
                 if not silent:
-                    print(f"loading latest backup: {tarpath}, {tarpath.stat().st_size / 1000 / 1000} MB")
+                    print(f"loading latest backup: \t\t {tarpath}")
             else:
                 if not silent:
                     print("nothing to load")
@@ -162,21 +151,24 @@ class Command(BaseCommand):
         else:
             tarpath = Path(tarpath)
             if not silent:
-                print(f"loading given backup: {tarpath}, {tarpath.stat().st_size / 1000 / 1000} MB")
+                print(f"loading given backup: \t\t {tarpath}")
 
         self.context['backup'] = tarpath
         info = extract_dumpinfo(str(tarpath))
         self.context['dump_version'] = info['dump_version']
         self.context['system_migration_files'] = self.system_migration_files
-        self.context['size_bytes'] = Path(tarpath).stat().st_size
+        size = Path(tarpath).stat().st_size
+        self.context['size_bytes'] = size
+        time = parse_datetime(info.get('created_at'))
 
         if not silent:
-            print(f"created at: {info['created_at']}")
-            print(f"[dump-version (for)]  \t {self.context['dump_version']}")
-            print(f"[system-version (now)]\t {self.context['system_version']}")
-            print(f"[dump-migrations]     \t {self.context['system_migration_files']}")
+            print(f"created at:\t\t\t {time.astimezone(tz=timezone.get_current_timezone())}")
+            print(f"size:\t\t\t\t {round(float(size / 1000 / 1000), 4)} MB")
+            print(f"dump-version:         \t\t {self.context['dump_version']}")
+            print(f"system-version (now): \t\t {self.context['system_version']}")
+            print(f"dump-migration-files: \t\t {info['dump_migration_files']} (files)")
             print(
-                f"[system-migrations]   \t {self.system_migration_files} (found) / {self.context['system_migrations_migrated']} (applied)\n")
+                f"system-migrations (now):\t {self.system_migration_files} (files) / {self.context['system_migrations_migrated']} (applied by MigrationRecorder)\n")
 
         if not loadmigrations:
             if self.migration_not_found:
@@ -214,9 +206,6 @@ class Command(BaseCommand):
 
         extract_tar(tarpath, member_path=BackupUtilsConfig.JSON_FILENAME)
 
-        if flush:
-            flush_db()
-
         if not skiptest:
             verbosity = 3
             if silent:
@@ -230,6 +219,9 @@ class Command(BaseCommand):
                 logger.error(f"failed unittest:\n{result.errors}")
                 raise UnittestFailed(message=f"unittest failed", output=str(result.errors[0]), **self.context)
 
+        if flush:
+            flush_db()
+
         load_database_dump(self.json_path, **self.context)
 
         if deletedirs:
