@@ -11,11 +11,13 @@ class MainAttributes(models.Model):
 
 
 class Backup(MainAttributes):
-    system_version = models.TextField(null=True, blank=True)
     dump_version = models.TextField(null=True, blank=True)
-    system_migrations_migrated = models.IntegerField("System Migrations", null=True, blank=True)
-    system_migration_files = models.IntegerField("Dump Migration Files", null=True, blank=True)
+    system_migrations_migrated = models.IntegerField("System Migrations (at dump time)", null=True, blank=True)
+    dump_migration_files = models.IntegerField("Dump Migration Files", null=True, blank=True)
     created_at = models.DateTimeField()
+    consistent_migrations = models.BooleanField("Consistent Migrations", default=False)
+
+    # inconsistent migrations occur if your migration recorder does not match your local migration files
 
     def __str__(self):
         return f"Backup {self.pk}"
