@@ -41,7 +41,12 @@ def synchronize_backups(request):
     if request.user.has_perm('django_backup_utils.add_backup'):
         logger.debug(f"user {request.user} has permission to synchronize")
         command = listbackups.Command()
-        backups_file = command.find_backup()
+        try:
+            backups_file = command.find_backup()
+        except FileNotFoundError as e:
+            messages.error(request, f"could not synchronize: {e}")
+            return HttpResponseRedirect(reverse_lazy("admin:django_backup_utils_backup_changelist"))
+
         # find missing backups:
         logger.debug(f"found backups {backups_file}")
         for backup in backups_file:
